.. _about:

About ScippNexus
================

Development
-----------

ScippNexus is an open source project by the `European Spallation Source ERIC <https://europeanspallationsource.se/>`_ (ESS).

License
-------

ScippNexus is available as open source under the `BSD-3 license <https://opensource.org/licenses/BSD-3-Clause>`_.

Citing ScippNexus
-----------------

Please cite the following:

.. image:: https://zenodo.org/badge/475453428.svg
   :target: https://zenodo.org/badge/latestdoi/475453428

To cite a specific version of ScippNexus, select the desired version on Zenodo to get the corresponding DOI.

Source code and development
---------------------------

ScippNexus is hosted and developed `on GitHub <https://github.com/scipp/scippnexus>`_.

Contributing to ScippNexus
--------------------------

Contributions, bug reports, and ideas are always welcome.
If in doubt whether a feature falls within the scope of ScippNexus please `ask on GitHub <https://github.com/scipp/scippnexus/issues>`_ before implementing functionality, to reduce the risk of rejected pull requests.
Asking and discussing first is generally always a good idea, since our road map is not very mature at this point.
